@@ -9,6 +9,7 @@ use {
         },
     },
     solana_client::rpc_client::RpcClient,
+    solana_core::tower_storage::FileTowerStorage,
     solana_faucet::faucet::{run_local_faucet_with_port, FAUCET_PORT},
     solana_rpc::rpc::JsonRpcConfig,
     solana_sdk::{
@@ -25,7 +26,7 @@ use {
     solana_streamer::socket::SocketAddrSpace,
     solana_validator::{
         admin_rpc_service, dashboard::Dashboard, ledger_lockfile, lock_ledger, println_name_value,
-        redirect_stderr_to_file, test_validator::*,
+        redirect_stderr_to_file, solana_test_validator::*,
     },
     std::{
         collections::HashSet,
@@ -508,6 +509,8 @@ fn main() {
     genesis.max_ledger_shreds = value_of(&matches, "limit_ledger_size");
     genesis.max_genesis_archive_unpacked_size = Some(u64::MAX);
 
+    let tower_storage = Arc::new(FileTowerStorage::new(ledger_path.clone()));
+
     let admin_service_cluster_info = Arc::new(RwLock::new(None));
     admin_rpc_service::run(
         &ledger_path,
@@ -521,6 +524,7 @@ fn main() {
             validator_exit: genesis.validator_exit.clone(),
             authorized_voter_keypairs: genesis.authorized_voter_keypairs.clone(),
             cluster_info: admin_service_cluster_info.clone(),
+            tower_storage: tower_storage.clone(),
         },
     );
     let dashboard = if output == Output::Dashboard {
@@ -538,6 +542,7 @@ fn main() {
 
     genesis
         .ledger_path(&ledger_path)
+        .tower_storage(tower_storage)
         .add_account(
             faucet_pubkey,
             AccountSharedData::new(faucet_lamports, 0, &system_program::id()),
